Move ssl_handshake_wrapup_free_hs_transform() to public namespace
diff --git a/include/mbedtls/ssl_internal.h b/include/mbedtls/ssl_internal.h
index 025c3a9..288297e 100644
--- a/include/mbedtls/ssl_internal.h
+++ b/include/mbedtls/ssl_internal.h
@@ -1091,4 +1091,6 @@
 void mbedtls_ssl_dtls_replay_reset( mbedtls_ssl_context *ssl );
 #endif
 
+void mbedtls_ssl_handshake_wrapup_free_hs_transform( mbedtls_ssl_context *ssl );
+
 #endif /* ssl_internal.h */
diff --git a/library/ssl_tls.c b/library/ssl_tls.c
index 3fcf2b9..206d07e 100644
--- a/library/ssl_tls.c
+++ b/library/ssl_tls.c
@@ -5567,8 +5567,6 @@
     return( 0 );
 }
 
-static void ssl_handshake_wrapup_free_hs_transform( mbedtls_ssl_context *ssl );
-
 /*
  * Read a record.
  *
@@ -6583,7 +6581,7 @@
         if( ssl->handshake != NULL &&
             ssl->state == MBEDTLS_SSL_HANDSHAKE_OVER  )
         {
-            ssl_handshake_wrapup_free_hs_transform( ssl );
+            mbedtls_ssl_handshake_wrapup_free_hs_transform( ssl );
         }
     }
 #endif /* MBEDTLS_SSL_PROTO_DTLS */
@@ -7987,7 +7985,7 @@
 #endif /* MBEDTLS_SHA512_C */
 #endif /* MBEDTLS_SSL_PROTO_TLS1_2 */
 
-static void ssl_handshake_wrapup_free_hs_transform( mbedtls_ssl_context *ssl )
+void mbedtls_ssl_handshake_wrapup_free_hs_transform( mbedtls_ssl_context *ssl )
 {
     MBEDTLS_SSL_DEBUG_MSG( 3, ( "=> handshake wrapup: final free" ) );
 
@@ -8067,7 +8065,7 @@
     }
     else
 #endif
-        ssl_handshake_wrapup_free_hs_transform( ssl );
+        mbedtls_ssl_handshake_wrapup_free_hs_transform( ssl );
 
     ssl->state++;
 
@@ -11984,7 +11982,8 @@
 
     /* mbedtls_ssl_reset() leaves the handshake sub-structure allocated,
      * which we don't want - otherwise we'd end up freeing the wrong transform
      * by calling ssl_handshake_wrapup_free_hs_transform() inappropriately. */
     if( ssl->handshake != NULL )
     {
         mbedtls_ssl_handshake_free( ssl );
@@ -11984,7 +11982,8 @@
     /* mbedtls_ssl_reset() leaves the handshake sub-structure allocated,
      * which we don't want - otherwise we'd end up freeing the wrong transform
-     * by calling ssl_handshake_wrapup_free_hs_transform() inappropriately. */
+     * by calling mbedtls_ssl_handshake_wrapup_free_hs_transform()
+     * inappropriately. */
     if( ssl->handshake != NULL )
     {